@@ -1,9 +1,7 @@
-from flowllm.utils.common_utils import load_env
 
-load_env()
 
-__version__ = "0.1.11.2"
+__version__ = "0.1.11.4"
 
 from flowllm.app import FlowLLMApp
-from flowllm.op import BaseOp, BaseAsyncOp, BaseAsyncToolOp, BaseMcpOp, BaseRayOp
 from flowllm.context.service_context import C
+from flowllm.op import BaseOp, BaseAsyncOp, BaseAsyncToolOp, BaseMcpOp, BaseRayOp
